#!/bin/sh

# All the connexion parameters are in an external file
. ~/.passwd

for c in ./configure ../configure; do
	if [ -x $c ] ; then
		CMD=$c
	fi
done

$CMD \
--release \
--siteurl="http://www.ufoot.org" \
--htprefix="" \
--dbhost=$UFOOT_ORG_DBHOST \
--dbname=$UFOOT_ORG_DBNAME \
--dbuser=$UFOOT_ORG_DBUSER \
--dbpasswd=$UFOOT_ORG_DBPASSWD \
--css_dir="/_uwikicms/template/css/ufoot"


